// Variables para setear
onload=function() {
	cAyuda=document.getElementById("mensajesAyuda");
	cNombre=document.getElementById("ayudaTitulo");
	cTex=document.getElementById("ayudaTexto");
	divTransparente=document.getElementById("transparencia");
	divMensaje=document.getElementById("transparenciaMensaje");
	
	urlDestino="ajax_registro.php";
	
	claseNormal="input";
	claseError="inputError";
	
	ayuda=new Array();
	ayuda["Nombre"]="Ingresa tu nombre. De 4 a 50 caracteres. OBLIGATORIO";
	ayuda["Empresa"]="Ingresa el nombre de tu Empresa. De 4 a 50 caracteres.";
	ayuda["Telefono"]="Ingresa un teléfono de contacto.";
	ayuda["Correo"]="Ingresa un e-mail válido. OBLIGATORIO";
	ayuda["Comentario"]="Ingresa tus comentarios. De 5 a 500 caracteres. OBLIGATORIO";
	
	preCarga("ok.gif", "loading.gif", "error.gif");
}

function preCarga() {
	imagenes=new Array();
	for(i=0; i<arguments.length; i++) {
		imagenes[i]=document.createElement("img");
		imagenes[i].src=arguments[i];
		}
	}

function nuevoAjax() { 
	var xmlhttp=false; 
	try { 
		// No IE
		xmlhttp=new ActiveXObject("Msxml2.XMLHTTP"); 
		}
	catch(e) { 
		try { 
			// IE 
			xmlhttp=new ActiveXObject("Microsoft.XMLHTTP"); 
			} 
		catch(E) { xmlhttp=false; }
		}
	if (!xmlhttp && typeof XMLHttpRequest!="undefined") { xmlhttp=new XMLHttpRequest(); } 
	return xmlhttp; 
	}

function limpiaForm() {
	for(i=0; i<=1; i++) {
		form.elements[i].className=claseNormal;
		}
	/*document.getElementById("inputComentario").className=claseNormal;*/
	}

function campoError(campo) {
	campo.className=claseError;
	error=1;
	}

function ocultaMensaje() {
	divTransparente.style.display="none";
	}

function muestraMensaje(mensaje) {
	divMensaje.innerHTML=mensaje;
	divTransparente.style.display="block";
	}

function eliminaEspacios(cadena) {
	// Funcion para eliminar espacios delante y detras de cada cadena
	while(cadena.charAt(cadena.length-1)==" ") cadena=cadena.substr(0, cadena.length-1);
	while(cadena.charAt(0)==" ") cadena=cadena.substr(1, cadena.length-1);
	return cadena;
	}

function validaLongitud(valor, permiteVacio, minimo, maximo) {
	var cantCar=valor.length;
	if(valor=="") {
		if(permiteVacio) return true;
		else return false;
		}
	else {
		if(cantCar>=minimo && cantCar<=maximo) return true;
		else return false;
		}
	}
function validaFecha(Cadena){  
    var Fecha= new String(Cadena)   // Crea un string 
    var RealFecha= new Date()   // Para sacar la fecha de hoy    
    var Ano= new String(Fecha.substring(Fecha.lastIndexOf("/")+1,Fecha.length))  
    var Mes= new String(Fecha.substring(Fecha.indexOf("/")+1,Fecha.lastIndexOf("/")))   
    var Dia= new String(Fecha.substring(0,Fecha.indexOf("/")))  
  
    if (isNaN(Ano) || Ano.length<4 || parseFloat(Ano)<1900) return false;
    if (isNaN(Mes) || parseFloat(Mes)<1 || parseFloat(Mes)>12) return false;
    if (isNaN(Dia) || parseInt(Dia, 10)<1 || parseInt(Dia, 10) > 31) return false ;
    if (Mes==4 || Mes==6 || Mes==9 || Mes==11 || Mes==2) {  
        if (Mes==2 && Dia > 28 || Dia>30) { 
            return false;
        	}  
    	}        
  return true;   
} 

function validaCorreo(valor) {
	var reg=/(^[a-zA-Z0-9._-]{1,30})@([a-zA-Z0-9.-]{1,30}$)/;
	if(reg.test(valor)) return true;
	else return false;
	}

function validaCombo(valor) {
	if(valor=="Ninguno") return false;
	else return true;
	}
	
function validaAcceso() {
	form=document.getElementById("FrmAcceso");
	alert(document.forms.length);	
	urlDestino="ajax_registro.php";
	limpiaForm(form);
	error=0;
	var msjError="";
	
	var usuario=eliminaEspacios(form.user.value);
	var clave=eliminaEspacios(form.pass.value);
	
	if(!validaLongitud(usuario, 0, 5, 20)) {
		campoError(form.user);
		msjError=msjError+"<b>Nombre de Usuario:</b> Debe Contener entre 5 y 20 Caraceteres<br>"
		}
	if(!validaLongitud(clave, 0, 5, 20)) {
		campoError(form.pass);
		msjError=msjError+"<b>Contraseña:</b> Debe Contener entre 5 y 20 Caraceteres<br>"
		}
	
	if(error==1) {
		var texto="<table width=350 border=0 cellpadding=0 cellspacing=0><tr><td width=40 align=center valign=middle><img src=\"images/error.gif\" width=32 height=32/></td><td width=310 valign=middle><font color=\"#FF0000\"><b>REVISE LOS CAMPOS EN ROJO</b></font></td></tr><tr><td colspan=2>"+msjError+"</td></tr><tr><td width=40 height=32 align=center valign=middle><td align=center valign=middle>&nbsp;&nbsp;&nbsp;&nbsp;<button style='width:70px; height:20px; font-size:10px;' onClick='ocultaMensaje()' type='button'>Aceptar</button></td></tr></table>";
		muestraMensaje(texto);
		}
	else {
		var texto="<img src='images/loading.gif' alt='Enviando'><br>Enviando. Por favor espere.<br><br><button style='width:60px; height:18px; font-size:10px;' onClick='ocultaMensaje()' type='button'>Ocultar</button>";
		muestraMensaje(texto);
		
		var ajax=nuevoAjax();
		ajax.open("POST", urlDestino, true);
		ajax.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
		ajax.send("apat="+apate+"&amat="+amate+"&nomb="+name+"&cdoc="+cdocu+"&ndoc="+ndocu+"&fnac="+fnaci+"&sex="+sexo+"&esci="+esciv+"&tele="+telef+"&celu="+celul+"&correo="+email+"&pais="+paiss+"&depa="+depar+"&prov="+provi+"&dist="+distr+"&czon="+czona+"&dzon="+dzona+"&cvia="+cviaa+"&dvia="+dviaa+"&nro="+numero+"&inte="+inter+"&user="+usuario+"&pass="+clave);
		
		ajax.onreadystatechange=function() {
			if (ajax.readyState==4) {
				var respuesta=ajax.responseText;
				if(respuesta=="OK") {
					var texto="<img src='images/ok.gif' alt='Ok'><br>Gracias por Registrarse.<br>En Nuestro Sistema<br>Ahora podra disfrutar de todos los beneficios<br><br><button style='width:45px; height:18px; font-size:10px;' onClick=\"location='index.php'\" type='button'>Ok</button>";
					}
				else {
					if(respuesta=="ndoc") {
						campoError(form.ndoc);
						msjError="<b>Nro. Documento:</b> El Nro. de Documento ya Existe<br>"
						}
					if(respuesta=="correo") {
						campoError(form.ndoc);
						msjError="<b>Correo Electronico:</b> El Correo Electronico ya Existe<br>"
						}
					if(respuesta=="user") {
						campoError(form.user);
						msjError="<b>Nombre Usuario:</b> El Usuario ya Existe<br>"
						}

					var texto="<table width=350 border=0 cellpadding=0 cellspacing=0><tr><td width=40 align=center valign=middle><img src=\"images/error.gif\" width=32 height=32/></td><td width=310 valign=middle><font color=\"#FF0000\"><b>REVISE LOS CAMPOS EN ROJO</b></font></td></tr><tr><td colspan=2>"+respuesta+"</td></tr><tr><td width=40 height=32 align=center valign=middle><td align=center valign=middle>&nbsp;&nbsp;&nbsp;&nbsp;<button style='width:70px; height:20px; font-size:10px;' onClick='ocultaMensaje()' type='button'>Aceptar</button></td></tr></table>";
					}
				muestraMensaje(texto);
			}
		}
	}
}