//Validar Acceso de Usuario
function validaAcceso() {
	urlDestino="funciones/fn_login.php";
	limpiaForm(NumElementos);
	error=0;
	msjError="";

	var usuario=eliminaEspacios(form.user.value);
	var clave=eliminaEspacios(form.pass.value);	
	if(!validaLongitud(usuario, 0, 3, 20)) {
		campoError(form.user);
		msjError=msjError+"<b>Usuario:</b> Debe Contener entre 3 y 20 Caraceteres<br>"
		}
	if(!validaLongitud(clave, 0, 5, 20)) {
		campoError(form.pass);
		msjError=msjError+"<b>Contraseņa:</b> Debe Contener entre 5 y 20 Caraceteres<br>"
		}
	
	if(error==1) muestraMensaje(VerMensaje("E",msjError));
	else {			
		muestraMensaje(VerMensaje("L",""));
		var ajax=nuevoAjax();
		ajax.open("POST", urlDestino, true);
		ajax.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
		ajax.send("user="+usuario+"&pass="+clave);
		ajax.onreadystatechange=function() {
			if (ajax.readyState==4) {
				var respuesta=ajax.responseText;
				if(respuesta=="OK") var texto = VerMensaje("A",form.user.value);
				else {
					if(respuesta=="user") {
						campoError(form.user);
						msjError="El Usuario <b>"+form.user.value+"</b> No existe<br>";
						}
					else if(respuesta=="clave") {
						campoError(form.pass);
						msjError="La Contraseņa es Incorrecta<br>";
						}
					else if(respuesta=="act") {
						campoError(form.pass);
						msjError="El Usuario <b>"+form.user.value+"</b> Esta Inactivo";
						}
					else msjError=respuesta;
					var texto=VerMensaje("E",msjError);
					}
				muestraMensaje(texto);
			}
		}
	}
}
